Description Usage Arguments Examples
View source: R/podlove_prepare_stats_for_graph.R
Takes clean Podlove data and prepares it to be rendered with ggplot2.
The function accepts one or more grouping variables (e.g. episode title) and
accepts parameters for the time axis of downloads.
1 2 3 4 5 6 7 8 | podlove_prepare_stats_for_graph(
df_stats,
gvar,
time_unit = "days",
relative = TRUE,
last_n = 0,
...
)
|
df_stats |
A data frame of clean Podlove data, as rendered by
|
gvar |
Optional grouping variable(s), unquoted. |
time_unit |
quoted time unit to group by: "hours", "days", "weeks", "months", "years" |
relative |
Boolean switching parameter to define if the data is
rendered relative to the respective episode release date ( |
last_n |
Number of most recent episodes to filter for. Defaults to 0 (no filtering), use negative numbers to filter for first n episodes. |
... |
Depreciated arguments |
1 2 3 4 5 6 7 8 9 10 11 12 13 14 | ## Not run:
# relative, daily plot by episode title
podlove_prepare_stats_for_graph(podcast_example_data, gvar = title)
# relative, hourly plot by episode number
podlove_prepare_stats_for_graph(podcast_example_data, gvar = ep_number, hourly = TRUE)
# absolute, daily plot by episode title
podlove_prepare_stats_for_graph(podcast_example_data, gvar = title, relative = FALSE)
# abolute, hourly plot by podcast client name
podlove_prepare_stats_for_graph(podcast_example_data, gvar = client_name, relative = FALSE)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.